![ATAK screenshot](https://raw.githubusercontent.com/ampledata/aprscot/main/docs/media/screenshot_1637083240_16797.png)

# Display APRS in TAK

APRSCOT is software for monitoring and analyzing APRS via the [Team Awareness Kit (TAK)](https://www.tak.gov) ecosystem of products.

APRSCOT captures & reports real-time APRS data received from over-the-air RF or Internet gateways, including APRS-IS.

[Documentation is available here.](https://aprscot.rtfd.io)

# License & Copyright

Copyright Sensors & Signals LLC https://www.snstac.com/

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

[Automatic Packet Reporting System (APRS)](http://www.aprs.org/) is Copyright Bob Bruninga WB4APR (SK) wb4apr@amsat.org
